@@ -119,8 +119,8 @@ cjs_tmb=function(x,ddl,dml,model_data=NULL,parameters,accumulate=TRUE,initial=NU
 #   Scale the design matrices and parameters with either input scale or computed scale of mean
 #   Currently no scaling
     scale=1
-	scale=set.scale(names(dml),model_data,scale)
-	model_data=scale.dm(model_data,scale)
+	scale=set_scale(names(dml),model_data,scale)
+	model_data=scale_dm(model_data,scale)
 
 		########################################################################
 #      CJS with TMB
@@ -332,7 +332,7 @@ cjs_tmb=function(x,ddl,dml,model_data=NULL,parameters,accumulate=TRUE,initial=NU
 		       if(p_nre+phi_nre>0)
 		       {
 			        par=par_summary$par.fixed[1:fixed.npar]
-			        cjs.beta.fixed=unscale.par(par,scale)
+			        cjs.beta.fixed=unscale_par(par,scale)
 			        cjs.beta.sigma=par_summary$par.fixed[-(1:fixed.npar)]
 			        sigma=NULL
 			        if(phi_krand>0)
@@ -351,7 +351,7 @@ cjs_tmb=function(x,ddl,dml,model_data=NULL,parameters,accumulate=TRUE,initial=NU
 			        beta.vcv=par_summary$cov.fixed
 		      }else
 		      {	
-			       cjs.beta=unscale.par(par,scale)
+			       cjs.beta=unscale_par(par,scale)
 			       if(hessian) 
 			       {
 				        message("Computing hessian...")
