@@ -11,21 +11,20 @@
 #' \code{\link{make.design.data}} to create the design data for each parameter
 #' in the specified model, 3) \code{\link{create.dm}} to create the design
 #' matrices for each parameter based on the formula provided for each
-#' parameter, 4) call to the specific function for model fitting (now either
-#' \code{\link{cjs_admb}} or \code{\link{js}}). As with \code{mark} the calling
+#' parameter, 4) call to the specific function for model fitting. As with \code{mark} the calling
 #' arguments for \code{crm} are a compilation of the calling arguments for each
 #' of the functions it calls (with some arguments renamed to avoid conflicts).
 #' expects to find a value for \code{ddl}.  Likewise, if the data have not been
 #' processed, then \code{ddl} should be NULL.  This dual calling structure
-#' allows either a single call approach for each model or alternatively for the
-#' data to be processed and the design data (\code{ddl}) to be created once and
+#' allows either a single call approach for each model or alternatively the preferred method
+#' where the data area processed and the design data (\code{ddl}) created once and
 #' then a whole series of models can be analyzed without repeating those steps.
 #' 
 #' There are some optional arguments that can be used to set initial values and
 #' control other aspects of the optimization.  The optimization is done with
 #' the R package/function \code{optimx} and the arguments \code{method} and
 #' \code{hessian} are described with the help for that function.  In addition,
-#' any arguments not matching those for \code{cjs_admb} (the ...) are passed to
+#' any arguments not matching those in the fitting functions (eg \code{cjs_admb}) are passed to
 #' \code{optimx} allowing any of the other parameters to be set.  If you set
 #' \code{debug=TRUE}, then at each function evaluation (\code{\link{cjs.lnl}}
 #' the current values of the parameters and -2*log-likelihood value are output.
@@ -38,18 +37,14 @@
 #' the link space are referred to as \code{beta} and those in the actual
 #' parameter space of \code{Phi} and \code{p} as reals.
 #' 
-#' Initial values can be set in 2 ways.  To set a baseline intial value for the
-#' intercept of \code{Phi} \code{p} set those arguments to some real value in
-#' the open interval (0,1). All non-intercept beta parameters are set to zero.
-#' Alternatively, you can specify in \code{initial}, a vector of initial values
-#' for the beta parameters (on the logit scale).  This is most easily done by
-#' passing the results from a previous model run using the result list element
-#' \code{beta} as described below.  The code will match the names of the
+#' Initial values can be set in 2 ways.  1) Define a list of named vectors with 
+#' the initial beta parameter values (eg logit link) in \code{initial}. 
+#' The names of the vectors should be the parameter names in the model. Any unspecified
+#' values are set to 0. 2) Specify a previously run model for initial. The code will match the names of the
 #' current design matrix to the names in \code{beta} and use the appropriate
-#' initial values. Any non-specified values are set to 0.  If there are no
-#' names associated with the \code{initial} vector then they are simply used in
-#' the specified order. If you do not specify initial values it is equivalent
-#' to setting \code{Phi} and \code{p} to 0.5.
+#' initial values. Any non-specified values are set to 0.  If no value is specified for initial,
+#' all beta are started at a value of 0, except for the CJS model which attempts to use a glm approach to
+#' setting starting values. If the glm fails then they are set to 0.
 #' 
 #' If you have a study with unequal time intervals between capture occasions,
 #' then these can be specified with the argument \code{time.intervals}.
@@ -118,17 +113,17 @@
 #' be included.
 #' 
 #' To use ADMB (use.admb=TRUE), you need to install: 1) the R package R2admb, 2) ADMB, and 3) a C++ compiler (I recommend gcc compiler).
-#' The following are instructions for installation with Windows. For other operating systems see (\url{http://www.admb-project.org/downloads}) and 
-#'  (\url{http://www.admb-project.org/tools/gcc/}). 
+#' The following are instructions for installation with Windows. For other operating systems see (\url{http://www.admb-project.org/}) and 
+#'  (\url{https://www.admb-project.org/tools/gcc/}). 
 #' 
 #' Windows Instructions:
 #'
 #'  1) In R use install.packages function or choose Packages/Install Packages from menu and select R2admb.
 #' 
-#'  2) Install ADMB 11: \url{http://www.admb-project.org/downloads}. Put the software in C:/admb to
+#'  2) Install ADMB 11: \url{https://www.admb-project.org/downloads/}. Put the software in C:/admb to
 #'  avoid problems with spaces in directory name and for the function below to work.
 #' 
-#'  3) Install gcc compiler from: \url{http://www.admb-project.org/tools/gcc/}. Put in c:/MinGW
+#'  3) Install gcc compiler from: \url{https://www.admb-project.org/tools/gcc/}. Put in c:/MinGW
 #' 
 #' I use the following function in R to setup R2admb to access ADMB rather than adding to my path so gcc versions
 #' with Rtools don't conflict. 
@@ -158,8 +153,8 @@
 #' @param design.parameters Specification of any grouping variables for design
 #' data for each parameter
 #' @param model.parameters List of model parameter specifications
-#' @param initial Optional vector of initial values for beta parameters; if
-#' named from previous analysis only relevant values are used
+#' @param initial Optional list of named vectors of initial values for beta parameters or a previously
+#' run model
 #' @param groups Vector of names factor variables for creating groups
 #' @param time.intervals Intervals of time between the capture occasions
 #' @param method optimization method 
@@ -194,6 +189,7 @@
 #' @param prior.list which contains list of prior parameters that will be model dependent
 #' @param useHess if TRUE, the TMB hessian function is used for optimization; using hessian is typically slower with many parameters but can result in a better solution
 #' @param optimize if TRUE, optimizes to get parameter estimates; set to FALSE to extract estimates of ADREPORTed values only
+#' @param unit_scale default TRUE, if FALSE any time scaled parameter (e.g. Phi,S) is scaled when computing real value such that it represents the length of the interval rather than a unit interval
 #' @param ... optional arguments passed to js or cjs and optimx
 #' @importFrom graphics boxplot par
 #' @importFrom stats as.formula binomial coef density
@@ -202,9 +198,12 @@
 #'              rnorm sd nlminb
 #' @importFrom utils capture.output flush.console
 #'             read.delim
+#' @importFrom methods as is
 #' @import data.table
-#' @return crm model object with class=("crm",submodel) where submodel is
-#' either "CJS" or "JS" at present.
+#' @import bookdown
+#' @import kableExtra
+#' @import knitr
+#' @return crm model object with class=("crm",submodel), eg "CJS".
 #' @author Jeff Laake
 #' @export crm
 #' @import optimx Matrix Rcpp numDeriv
@@ -215,16 +214,24 @@
 #' @examples
 #' {
 #' # cormack-jolly-seber model
-#' # fit 3 cjs models with crm
+#' # fit cjs models with crm
 #' data(dipper)
 #' dipper.proc=process.data(dipper,model="cjs",begin.time=1)
 #' dipper.ddl=make.design.data(dipper.proc)
 #' mod.Phit.pt=crm(dipper.proc,dipper.ddl,
 #'    model.parameters=list(Phi=list(formula=~time),p=list(formula=~time)))
 #' mod.Phit.pt
-#' mod.Phisex.pdot=crm(dipper.proc,dipper.ddl,groups="sex",
+#' mod.Phisex.pdot=crm(dipper.proc,dipper.ddl,
 #'    model.parameters=list(Phi=list(formula=~sex),p=list(formula=~1)))
 #' mod.Phisex.pdot
+#' # demo initial value setting
+#' mod.Phisex.ptime=crm(dipper.proc,dipper.ddl,
+#'    model.parameters=list(Phi=list(formula=~sex),p=list(formula=~time)),initial=mod.Phit.pt)
+#' mod.Phisex.ptime
+#' mod.Phisex.ptime=crm(dipper.proc,dipper.ddl,
+#'    model.parameters=list(Phi=list(formula=~sex),p=list(formula=~time)),initial=list(Phi=0,p=0))
+#' mod.Phisex.ptime
+#' 
 #' ## if you have RMark installed you can use this code to run the same models 
 #' ## by removing the comment symbol
 #' #library(RMark)
@@ -241,6 +248,22 @@
 #' # jolly seber model
 #' crm(dipper,model="js",groups="sex",
 #'    model.parameters=list(pent=list(formula=~sex),N=list(formula=~sex)),accumulate=FALSE)
+#' # examples showing use of unit.scale
+#' dipper.proc=process.data(dipper,model="cjs",begin.time=1,time.intervals=c(.1,.2,.3,.4,.5,.6))
+#' dipper.ddl=make.design.data(dipper.proc)
+#' mod.Phit.p=crm(dipper.proc,dipper.ddl,
+#'                model.parameters=list(Phi=list(formula=~time),p=list(formula=~1)),
+#'                hessian=TRUE,unit_scale=TRUE)
+#' mod.Phit.p
+#' mod.Phit.p$results$reals
+#' 
+#' dipper.proc=process.data(dipper,model="cjs",begin.time=1,time.intervals=c(.1,.2,.3,.4,.5,.6))
+#' dipper.ddl=make.design.data(dipper.proc)
+#' mod.Phit.p=crm(dipper.proc,dipper.ddl,
+#'                model.parameters=list(Phi=list(formula=~time),p=list(formula=~1)),
+#'                hessian=TRUE,unit_scale=FALSE)
+#' mod.Phit.p
+#' mod.Phit.p$results$reals
 #' \donttest{
 #' # This example is excluded from testing to reduce package check time
 #' # if you have RMark installed you can use this code to run the same models 
@@ -268,16 +291,9 @@
 crm <- function(data,ddl=NULL,begin.time=1,model="CJS",title="",model.parameters=list(),design.parameters=list(),initial=NULL,
  groups = NULL, time.intervals = NULL,debug=FALSE, method=NULL, hessian=FALSE, accumulate=TRUE,chunk_size=1e7, 
  control=list(),refit=1,itnmax=5000,scale=NULL,run=TRUE,burnin=100,iter=1000,use.admb=FALSE,use.tmb=FALSE,crossed=NULL,reml=FALSE,compile=FALSE,extra.args=NULL,
- strata.labels=NULL,clean=NULL,save.matrices=FALSE,simplify=FALSE,getreals=FALSE,real.ids=NULL,check=FALSE,prior=FALSE,prior.list=NULL,useHess=FALSE,optimize=TRUE,...)
+ strata.labels=NULL,clean=NULL,save.matrices=FALSE,simplify=FALSE,getreals=FALSE,real.ids=NULL,check=FALSE,prior=FALSE,prior.list=NULL,useHess=FALSE,optimize=TRUE,unit_scale=TRUE,...)
 {
 model=toupper(model)
-if(is.null(method))
-{
-  if(substr(model,1,4)=="MVMS")
-    method="nlminb"
-  else
-    method="BFGS"
-}
 ptm=proc.time()
 if(is.null(crossed))crossed=FALSE
 if(crossed)accumulate=FALSE
@@ -303,6 +319,15 @@ else
 	data.proc=data
 	model=data$model
 }
+if(is.null(method))
+{
+  if(substr(model,1,4)%in%c("MVMS","MSLD"))
+    method="nlminb"
+  else
+    method="BFGS"
+}
+if(model%in%c("MSLD"))
+  use.tmb=TRUE
 #
 # Setup parameter list
 #
@@ -357,6 +382,7 @@ if((use.tmb|toupper(model)%in%c("MSLD"))&is.null(clean))clean=FALSE
 #
 # If the design data have not been constructed, do so now
 #
+external.ddl=FALSE
 if(is.null(ddl)) 
 {
   if(debug)message("Creating design data...\n")
@@ -364,6 +390,18 @@ if(is.null(ddl))
 	ddl=make.design.data(data.proc,design.parameters)
 } else
 {
+  if(is.character(ddl)&&toupper(ddl)=="EXTERNAL")
+  {
+    external.ddl=TRUE
+    if(file.exists("ddl.rda"))
+    {
+      load(file="ddl.rda")
+      if(!exists("ddl")) stop("\nexternal ddl.rda file must contain object named ddl")
+    } else
+    {
+      stop("\nCannot find external file named ddl.rda")
+    }
+  }
 	for (i in 1:length(parameters))
 	{
 		if(!is.null(ddl[[i]]$order))
@@ -417,22 +455,19 @@ if(substr(model,1,4)=="MVMS"&check)
 	  }
 	}
 }
-fullddl=ddl
-if(model=="MSCJS" | model=="MSLD" | (substr(model,1,4)=="MVMS" & (use.admb | use.tmb))) 
+if(model=="MSCJS" | model%in%c("MSLD") | (substr(model,1,4)=="MVMS" & (use.admb | use.tmb))) 
 {
+  fullddl=ddl
   if(debug)message("Simplifying design data\n")
 	ddl=simplify_ddl(ddl,parameters) # add indices to ddl and reduce ddl to unique values used
 }
+else 
+  fullddl=NULL
 if(simplify)
 {
 	simplify=FALSE
 	message("\nsimplify argument has been disabled")
 }
-#if(simplify & !(substr(model,1,3)=="HMM"|(nchar(model)>=4 &substr(model,1,4)=="MVMS")))
-#{
-#	simplify=FALSE
-#	message("Can only use simplify with HMM models. simplify set to FALSE")
-#}
 # check to see if all values for a parameter have been fixed.  If so, then set formula to ~0
 for (i in 1:length(parameters))
 {
@@ -453,15 +488,15 @@ for (i in 1:length(parameters))
 # Create design matrices for each parameter
 if(debug)message("Creating design matrices\n")
 dml=create.dml(ddl,model.parameters=parameters,design.parameters=design.parameters,chunk_size=chunk_size,simplify=simplify,use.admb=use.admb)
-if(model=="MSCJS"| model=="MSLD"|(substr(model,1,4)=="MVMS" & (use.admb | use.tmb))&(check|save.matrices)) {
+if(model=="MSCJS"| model%in%c("MSLD")|(substr(model,1,4)=="MVMS" & (use.admb | use.tmb)))
+  {
   fulldml=dml
   for(parx in names(dml))
   {
     fulldml[[parx]]$fe=dml[[parx]]$fe[ddl[[paste(parx,".indices",sep="")]],,drop=FALSE]
     parameters[[parx]]$indices=ddl[[paste(parx,".indices",sep="")]]    
   }
-} else
-  fulldml=dml
+} 
 # For HMM call set.initial to get ptype and set initial values
 if(substr(model,1,3)=="HMM"|(nchar(model)>=4 &substr(model,1,4)=="MVMS"))
 	initial.list=set.initial(names(dml),dml,initial)
@@ -505,9 +540,32 @@ if(model=="MSCJS")
 	    runmodel=mscjs(data.proc,ddl,dml,parameters=parameters,initial=initial,method=method,hessian=hessian,debug=debug,accumulate=accumulate,chunk_size=chunk_size,
 				   refit=refit,control=control,itnmax=itnmax,scale=scale,re=re,compile=compile,extra.args=extra.args,clean=clean,...)
   }
-if(model=="MSLD")
-    runmodel=msld_tmb(data.proc,ddl,fullddl,dml,parameters=parameters,initial=initial,method=method,hessian=hessian,debug=debug,accumulate=accumulate,chunk_size=chunk_size,
-                       refit=refit,control=control,itnmax=itnmax,scale=scale,re=re,compile=compile,extra.args=extra.args,clean=clean,getreals=getreals,useHess=useHess,...)
+if(model%in%c("MSLD"))
+{
+  save(fullddl,file="tmp.rda")
+  rm(fullddl)
+  runmodel=msld_tmb(data.proc,ddl,dml,parameters=parameters,initial=initial,method=method,hessian=hessian,debug=debug,accumulate=accumulate,chunk_size=chunk_size,
+                    refit=refit,control=control,itnmax=itnmax,scale=scale,re=re,compile=compile,extra.args=extra.args,
+                    clean=clean,getreals=getreals,useHess=useHess,savef=save.matrices,...)
+  if(save.matrices){
+    runmodel$mat=runmodel$f$report()
+    names(runmodel$mat)=c("dmat","gamma") 
+    runmodel$mat$delta=matrix(0,nrow=nrow(data.proc$data),ncol=length(data.proc$strata.labels)*2+1)
+    for(i in 1:nrow(data.proc$data))
+        runmodel$mat$delta[i,data.proc$start[i,1]]=1
+    # Adjust dmat to have nocc+1 entries for time to work with global decode
+    temp=array(0,dim=c(dim(runmodel$mat$dmat)[1],dim(runmodel$mat$dmat)[2]+1,dim(runmodel$mat$dmat)[3],dim(runmodel$mat$dmat)[4]))
+    temp[,2:dim(temp)[2],,]=runmodel$mat$dmat
+    for(i in 1:nrow(temp))
+      for(j in 1:length(data.proc$strata.labels))
+      {
+        temp[i,data.proc$start[i,2],j+1,j]=1
+        temp[i,data.proc$start[i,2],1,j]=0
+      }
+    runmodel$mat$dmat=temp
+  }
+  load("tmp.rda")
+}
 if(model=="PROBITCJS")
 {
 	if(is.null(initial))
@@ -568,12 +626,18 @@ if(substr(model,1,3)=="HMM"|(nchar(model)>=4 &substr(model,1,4)=="MVMS"))
 		runmodel$convergence=runmodel$optim.details$convcode
 		runmodel$options=list(accumulate=accumulate,initial=initial.list$par,method=method,
 				chunk_size=chunk_size,itnmax=itnmax,control=control,use.tmb=use.tmb,use.admb=use.admb)
+		runmodel$model_data=list(Phi.dm=dml$Phi$fe,p.dm=dml$p$fe,delta.dm=dml$delta$fe,Psi.dm=dml$Psi$fe,pi.dm=dml$pi$fe)
+		#S.fixed,r.fixed,p.fixed,Psi.fixed and time.intervals
 	}
 		if(save.matrices)
 		{
-			runmodel$mat=HMMLikelihood(par=par,type=initial.list$ptype,xx=data.proc$ehmat,mx=mx,T=data.proc$nocc,xstart=data.proc$start,freq=data.proc$freq,
-					fct_dmat=data.proc$fct_dmat,fct_gamma=data.proc$fct_gamma,fct_delta=data.proc$fct_delta,ddl=fullddl,dml=fulldml,parameters=parameters,return.mat=TRUE,sup=sup)
-			if(model=="HMMCJS")
+		  if(!is.null(fullddl))
+			   runmodel$mat=HMMLikelihood(par=par,type=initial.list$ptype,xx=data.proc$ehmat,mx=mx,T=data.proc$nocc,xstart=data.proc$start,freq=data.proc$freq,
+				   	fct_dmat=data.proc$fct_dmat,fct_gamma=data.proc$fct_gamma,fct_delta=data.proc$fct_delta,ddl=fullddl,dml=fulldml,parameters=parameters,return.mat=TRUE,sup=sup)
+		  else
+		    runmodel$mat=HMMLikelihood(par=par,type=initial.list$ptype,xx=data.proc$ehmat,mx=mx,T=data.proc$nocc,xstart=data.proc$start,freq=data.proc$freq,
+		                               fct_dmat=data.proc$fct_dmat,fct_gamma=data.proc$fct_gamma,fct_delta=data.proc$fct_delta,ddl=ddl,dml=dml,parameters=parameters,return.mat=TRUE,sup=sup)
+		  if(model=="HMMCJS")
 			{
 				dimnames(runmodel$mat$gamma)[3:4]=list(c("Alive","Dead"),c("Alive","Dead"))
 				dimnames(runmodel$mat$dmat)[3:4]=list(c("Missed","Seen"),c("Alive","Dead"))
@@ -619,10 +683,10 @@ if(!is.null(runmodel$convergence) && runmodel$convergence!=0&!use.admb)
 object=list(model=model,data=data.proc,model.parameters=parameters,design.parameters=design.parameters,results=runmodel)
 class(object)=class(runmodel)
 if(!use.tmb&!re & !model%in%c("MSCJS","MSLD") & (nchar(model)<4 | (nchar(model)>=4 & substr(model,1,4)!="MVMS")))
-   object$results$reals=predict(object,ddl=ddl,unique=TRUE,se=hessian)
+   object$results$reals=predict(object,ddl=ddl,unique=TRUE,se=hessian,unit_scale=unit_scale)
 #if(use.tmb & (nchar(model)>=4 & substr(model,1,4)=="MVMS") & getreals)
 #  object$results$reals=predict(object,ddl=ddl,real.ids=real.ids,se=hessian)
-
+if(file.exists("tmp.rda"))unlink("tmp.rda")
 message(paste("\nElapsed time in minutes: ",round((proc.time()[3]-ptm[3])/60,digits=4),"\n"))
 return(object)
 }
