@@ -180,8 +180,8 @@ mscjs=function(x,ddl,dml,model_data=NULL,parameters,accumulate=TRUE,initial=NULL
 #   p.links=which(p.links==1)
 #  Scale the design matrices and parameters with either input scale or computed scale
     scale=1
-	scale=set.scale(names(dml),model_data,scale)
-	model_data=scale.dm(model_data,scale)
+	scale=set_scale(names(dml),model_data,scale)
+	model_data=scale_dm(model_data,scale)
 	# setup tpl to be multistate.tpl 
 	if(!re)
 		tpl="multistate"
@@ -267,7 +267,7 @@ mscjs=function(x,ddl,dml,model_data=NULL,parameters,accumulate=TRUE,initial=NULL
 	convergence=attr(xx,"status")
 	if(is.null(convergence))convergence=0
 	res=read_admb(tpl)
-	beta=list(unscale.par(c(res$coeflist$phibeta,res$coeflist$pbeta,res$coeflist$psibeta),scale))
+	beta=list(unscale_par(c(res$coeflist$phibeta,res$coeflist$pbeta,res$coeflist$psibeta),scale))
 	parnames=names(unlist(beta))
 	fixed.npar=length(unlist(beta))
 	if(!is.null(res$hes))
