@@ -8,21 +8,26 @@
 #' error that the number of columns in the design matrix does not match the number of beta parameters.  You cannot 
 #' change the levels of any factor variable or modify the design data in anyway that changes the design matrix.
 #' 
+#' If the real estimates are in the model object and se and vcv are FALSE and ddl not specified, 
+#' the code will simply pull the values from the model object.
+#' 
+#' 
 #' @usage \method{predict}{crm}(object,newdata=NULL,ddl=NULL,parameter=NULL,unique=TRUE,
 #'                    vcv=FALSE,se=FALSE,chat=1,subset=NULL,select=NULL,
-#'                    real.ids=NULL,merge=FALSE,...)
+#'                    real.ids=NULL,merge=FALSE,unit_scale=TRUE,...)
 #' @param object model object;
 #' @param newdata a dataframe for crm 
-#' @param ddl list of dataframes for design data
+#' @param ddl list of dataframes for design data; if specified forces computation even if estimates are in model object
 #' @param parameter name of real parameter to be computed (eg "Phi")
-#' @param unique TRUE if only unique values should be returned
-#' @param vcv logical; if TRUE, computes and returns v-c matrix of real estimates
+#' @param unique TRUE if only unique values should be returned; if TRUE forces computation even if estimates are in model object
+#' @param vcv logical; if TRUE, computes and returns v-c matrix of real estimates; if TRUE forces computation even if estimates are in model object
 #' @param se logical; if TRUE, computes std errors and conf itervals of real estimates
 #' @param chat over-dispersion value
 #' @param subset logical expression using fields in real dataframe
 #' @param select character vector of field names in real that you want to include
 #' @param real.ids animal ids passed to TMB code for computation of real parameter values
 #' @param merge default FALSE but if TRUE, the ddl for the parameter is merged (cbind) to the estimates
+#' @param unit_scale default TRUE, if FALSE any time scaled parameter (e.g. Phi,S) is scaled when computing real value such that it represents the length of the interval rather than a unit interval
 #' @param ... generic arguments not used here
 #' @return A data frame (\code{real}) is returned if \code{vcv=FALSE};
 #' otherwise, a list is returned also containing vcv.real: \item{real}{ data
@@ -43,7 +48,7 @@
 #' xx
 #' @keywords utility
 predict.crm <-function(object,newdata=NULL,ddl=NULL,parameter=NULL,unique=TRUE,vcv=FALSE,se=FALSE,
-                       chat=1,subset=NULL,select=NULL,real.ids=NULL,merge=FALSE,...)
+                       chat=1,subset=NULL,select=NULL,real.ids=NULL,merge=FALSE,unit_scale=TRUE,...)
 {
   # if(object$model=="MVMSCJS")
   # {
@@ -101,7 +106,7 @@ predict.crm <-function(object,newdata=NULL,ddl=NULL,parameter=NULL,unique=TRUE,v
 	{
 		if(is.null(ddl))
 		{
-			if(!is.null(object$results$reals))
+			if(!is.null(object$results$reals)&!(se||vcv))
 				return(object$results$reals)
 			else{
 				if(!is.null(object$results$model_data$ddl))
@@ -121,8 +126,8 @@ predict.crm <-function(object,newdata=NULL,ddl=NULL,parameter=NULL,unique=TRUE,v
 	{
 		results=NULL
 		for (parameter in names(object$model.parameters))
-			results[[parameter]]=compute_real(object,parameter,ddl,dml,unique,vcv,se,chat,subset=substitute(subset),select,include=object$model.parameters[[parameter]]$include,merge=merge)
+			results[[parameter]]=compute_real(object,parameter,ddl,dml,unique,vcv,se,chat,subset=substitute(subset),select,include=object$model.parameters[[parameter]]$include,merge=merge,unit_scale=unit_scale)
 		return(results)
 	} else
-		return(compute_real(object,parameter,ddl,dml,unique,vcv,se,chat,subset=substitute(subset),select,include=object$model.parameters[[parameter]]$include,merge=merge))	
+		return(compute_real(object,parameter,ddl,dml,unique,vcv,se,chat,subset=substitute(subset),select,include=object$model.parameters[[parameter]]$include,merge=merge,unit_scale=unit_scale))	
 }
